@@ -9,7 +9,6 @@
 #include <QDebug>
 #include <QJsonArray>
 #include <QJsonDocument>
-#include <QJsonObject>
 
 const QString TIMERPRESETS_CFG_GROUP = QStringLiteral("TimerPresets"), TIMERPRESETS_CFG_KEY = QStringLiteral("timerPresets");
 
@@ -96,7 +95,7 @@ void TimerPresetModel::save()
 {
     QJsonArray arr;
 
-    const auto presets = qAsConst(m_presets);
+    const auto presets = std::as_const(m_presets);
     std::transform(presets.begin(), presets.end(), std::back_inserter(arr), [](const TimerPreset *preset) {
         return QJsonValue(preset->toJson());
     });
@@ -130,7 +129,7 @@ int TimerPresetModel::rowCount(const QModelIndex &parent) const
     return parent.isValid() ? 0 : m_presets.count();
 }
 
-void TimerPresetModel::insertPreset(QString presetName, int presetDuration)
+void TimerPresetModel::insertPreset(const QString &presetName, int presetDuration)
 {
     Q_EMIT beginInsertRows({}, 0, 0);
     m_presets.insert(0, new TimerPreset(this, presetName, presetDuration));
